// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_PLASMA_NM_KDED_LOG_PLASMA_NM_KDED_H
#define ECM_QLOGGINGCATEGORY_PLASMA_NM_KDED_LOG_PLASMA_NM_KDED_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(PLASMA_NM_KDED_LOG)


#endif
